summaryrefslogtreecommitdiff
path: root/fml/lib/FML/Command/User/admin.pm
diff options
context:
space:
mode:
authorfukachan <fukachan>2003-12-31 04:01:34 +0000
committerfukachan <fukachan>2003-12-31 04:01:34 +0000
commit96ebbc089d895bbcde5355cfa7295796b60e03b1 (patch)
treec12b2090c3b1f8fb11947ad15cfbec9c2d3502de /fml/lib/FML/Command/User/admin.pm
parent26d51a4a00991f549a1b4a5df7b6b050839f17ca (diff)
downloadfml8-96ebbc089d895bbcde5355cfa7295796b60e03b1.tar.gz
fml8-96ebbc089d895bbcde5355cfa7295796b60e03b1.tar.bz2
fml8-96ebbc089d895bbcde5355cfa7295796b60e03b1.zip
update comments.
sort 'use ..' phrase.
Diffstat (limited to 'fml/lib/FML/Command/User/admin.pm')
-rw-r--r--fml/lib/FML/Command/User/admin.pm22
1 files changed, 14 insertions, 8 deletions
diff --git a/fml/lib/FML/Command/User/admin.pm b/fml/lib/FML/Command/User/admin.pm
index df562a66..d4a2b5ee 100644
--- a/fml/lib/FML/Command/User/admin.pm
+++ b/fml/lib/FML/Command/User/admin.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: admin.pm,v 1.1 2003/01/03 06:45:45 fukachan Exp $
+# $FML: admin.pm,v 1.2 2003/02/09 12:31:42 fukachan Exp $
#
package FML::Command::User::admin;
@@ -13,9 +13,6 @@ use vars qw(@ISA @EXPORT @EXPORT_OK $AUTOLOAD);
use Carp;
-use FML::Command::Admin::password;
-
-
# Descriptions: constructor.
# Arguments: OBJ($self)
# Side Effects: none
@@ -29,21 +26,28 @@ sub new
}
# Descriptions: rewrite buffer to hide the password phrase in $rbuf
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args) STR_REF($rbuf)
-# Side Effects: none
+# Side Effects: rewrite buffer to hide the password phrase in $rbuf.
# Return Value: none
sub rewrite_prompt
{
my ($self, $curproc, $command_args, $rbuf) = @_;
+
+ # XXX-TODO: good style? FML::Command::Admin::password->rewrite_prompt() ?
+ use FML::Command::Admin::password;
my $obj = new FML::Command::Admin::password;
$obj->rewrite_prompt($curproc, $command_args, $rbuf);
}
+# XXX-TODO: process() is not implementd. correct ?
+
+
=head1 NAME
-FML::Command::User::admin - dummy but provide utility for the case auth fail.
+FML::Command::User::admin - dummy.
=head1 SYNOPSIS
@@ -51,7 +55,9 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-forward request to C<FML::Command::User::subscribe> module.
+In fact, this module is dummy but provide utility for the case auth
+fail. It rewrites buffer to hide the password phrase in command
+prompt.
=head1 CODING STYLE
@@ -29,21 +26,28 @@ sub new
}
-# Descriptions: rewrite buffer to hide the password phrase in $rbuf
+# Descriptions: rewrite command prompt.
+# Always we need to rewrite command prompt to hide password.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args) STR_REF($rbuf)